| lsh_add | R Documentation |
This function adds buckets for one or more new documents to an existing
lsh_buckets object. Use the same bands value and minhash
function that were used to create the original buckets.
lsh_add(buckets, x, bands, progress = interactive())
buckets |
An |
x |
A |
bands |
The number of bands to use for locality sensitive hashing. The
number of hashes in the documents in the corpus must be evenly divisible by
the number of bands. See |
progress |
Display a progress bar while comparing documents. |
An updated lsh_buckets object.
lsh, lsh_query,
lsh_candidates
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.