wordcount: Count words

View source: R/wordcount.R

wordcountR Documentation

Count words

Description

This function counts words in a text, for example, a character vector, a TextReuseTextDocument, some other object that inherits from TextDocument, or a all the documents in a TextReuseCorpus.

Usage

wordcount(x)

Arguments

x

The object containing a text.

Value

An integer vector for the word count.


textreuse documentation built on July 26, 2026, 1:06 a.m.