This function adds buckets for one or more new documents to an existing
lsh_buckets object. Use the same bands value and minhash
function that were used to create the original buckets.
lsh_add(buckets, x, bands, progress = interactive())An updated lsh_buckets object.
An lsh_buckets object created by lsh.
A TextReuseCorpus or
TextReuseTextDocument with minhashes.
The number of bands to use for locality sensitive hashing. The
number of hashes in the documents in the corpus must be evenly divisible by
the number of bands. See lsh_threshold and
lsh_probability for guidance in selecting the number of bands
and hashes.
Display a progress bar while comparing documents.
lsh, lsh_query,
lsh_candidates